Scrapple 0.2.2 documentation — Scrapple 0.2.2 documentation

### Navigation

- index
- next |
- Scrapple 0.2.2 documentation »

# Scrapple 0.2.2 documentation

Scrapple is a project aimed at designing a framework for building web content extractors. Scrapple uses key-value based configuration files to define parameters to be considered in generating the extractor. It considers the base page URL, selectors for each data to be extracted, and the selector for the links to be crawled through.

Scrapple can be used to generate single page content extractors or link crawlers.

This documentation contains information about how to use Scrapple and how Scrapple works.

## Overview

Introducing Scrapple
  An introduction to Scrapple
Install Scrapple
  Instructions for installing Scrapple and the required dependencies
Scrapple tutorial
  An intoductory tutorial to using Scrapple for generating the required scrapers/crawlers

## Concepts

Scrapple commands
  Commands provided by the Scrapple CLI
Configuration file
  The configuration file which is used by Scrapple to implement the required extractor/crawler

## Contribution guide

This part contains information about contributing to the project.

Authors
  Contributors to the project
Contributing
  Details about contributing to Scrapple

## Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Scrapple 0.2.2 documentation »